@@ -63,6 +63,8 @@ from .type_defs import (
     PushNotificationConfigurationTypeDef,
     PutChannelMembershipPreferencesResponseTypeDef,
     RedactChannelMessageResponseTypeDef,
+    SearchChannelsResponseTypeDef,
+    SearchFieldTypeDef,
     SendChannelMessageResponseTypeDef,
     TagTypeDef,
     UpdateChannelFlowResponseTypeDef,
@@ -170,7 +172,10 @@ class ChimeSDKMessagingClient(BaseClient):
         Mode: ChannelModeType = ...,
         Privacy: ChannelPrivacyType = ...,
         Metadata: str = ...,
-        Tags: Sequence[TagTypeDef] = ...
+        Tags: Sequence[TagTypeDef] = ...,
+        ChannelId: str = ...,
+        MemberArns: Sequence[str] = ...,
+        ModeratorArns: Sequence[str] = ...
     ) -> CreateChannelResponseTypeDef:
         """
         Creates a channel to which you can add users and send messages.
@@ -569,6 +574,21 @@ class ChimeSDKMessagingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#redact_channel_message)
         """
 
+    def search_channels(
+        self,
+        *,
+        Fields: Sequence[SearchFieldTypeDef],
+        ChimeBearer: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> SearchChannelsResponseTypeDef:
+        """
+        Allows an `AppInstanceUser` to search the channels that they belong to.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.search_channels)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client/#search_channels)
+        """
+
     def send_channel_message(
         self,
         *,
@@ -614,9 +634,9 @@ class ChimeSDKMessagingClient(BaseClient):
         self,
         *,
         ChannelArn: str,
-        Name: str,
-        Mode: ChannelModeType,
         ChimeBearer: str,
+        Name: str = ...,
+        Mode: ChannelModeType = ...,
         Metadata: str = ...
     ) -> UpdateChannelResponseTypeDef:
         """
