@@ -31,6 +31,8 @@ __all__ = (
     "FallbackActionType",
     "InvocationTypeType",
     "PushNotificationTypeType",
+    "SearchFieldKeyType",
+    "SearchFieldOperatorType",
     "SortOrderType",
     "ChimeSDKMessagingServiceName",
     "ServiceName",
@@ -66,6 +68,8 @@ ErrorCodeType = Literal[
 FallbackActionType = Literal["ABORT", "CONTINUE"]
 InvocationTypeType = Literal["ASYNC"]
 PushNotificationTypeType = Literal["DEFAULT", "VOIP"]
+SearchFieldKeyType = Literal["MEMBERS"]
+SearchFieldOperatorType = Literal["EQUALS", "INCLUDES"]
 SortOrderType = Literal["ASCENDING", "DESCENDING"]
 ChimeSDKMessagingServiceName = Literal["chime-sdk-messaging"]
 ServiceName = Literal[
